-- Author      : jkonkle
-- Create Date : 6/22/2009 8:22:49 PM
-- Config collections and functions

-- OPTIONS
-- enableDAL - toggles handling loot (ie. it ignores LOOT_OPENED events)
-- enableBS - toggles printing of summary of all bids or just winner
-- bidTime - input value for length of bid
-- defaultSharder - input value for who to send shards to
local options = {
	name = "Devil's Advocate Loot",
	handler = DALoot,
	type = "group",
	args = {
		enableDAL = {
			order=1, type = "toggle",
			name = "Enable DA Loot",
			desc = "Enables the master looting management by DALoot",
			get = function(info) return(DALoot.db.profile.enableDAL) end,
			set = function(info, key) DALoot.db.profile.enableDAL=key end
		},bidSummaryCount={
			order=2, type = "input",
			name = "Bid Summary",
			desc = "How many bids to output in Summary (0 for none)",
			get = function(info) return(DALoot.db.profile.bidSummaryCount) end,
			set = function(info, key) DALoot.db.profile.bidSummaryCount=key end
		},bidTime={
			order=3, type = "input",
			name = "Bid Time",
			desc = "How long people have to bid for each loot item",
			get = function(info) return(DALoot.db.profile.bidTime) end,
			set = function(info, key) DALoot.db.profile.bidTime=key end
		},countdownTime={
			order=4, type = "input",
			name = "Countdown Time",
			desc = "Countdown timer in chat (0 for none)",
			get = function(info) return(DALoot.db.profile.countdownTime) end,
			set = function(info, key) DALoot.db.profile.countdownTime=key end
		},defaultSharder = {
			order=5, type = "input",
			name = "Default Sharder",
			desc = "Default person to master loot shards to",
			get = function(info) return(DALoot.db.profile.defaultSharder) end,
			set = function(info, key) DALoot.db.profile.defaultSharder=key end
		},outputChannel = {
			order=6, type="select",
			name = "Output Channel",
			desc = "Channel to output all text",
			values = { 	["RAID"] = "Raid Chat",
						["PARTY"] = "Group Chat",
						["GUILD"] = "Guild" },
			get = function(info) return (DALoot.db.profile.outputChannel) end,
			set = function(info, key) DALoot.db.profile.outputChannel=key end
		},raidAnnounce = {
			order=7, type = "toggle",
			name = "Announce in Raid Warning",
			desc = "New rolls are announced as a Raid Warning",
			get = function(info) return(DALoot.db.profile.raidAnnounce) end,
			set = function(info, key) DALoot.db.profile.raidAnnounce=key end
		},lootRules = {
			order=8, type = "input",
			name = "Loot Rules",
			desc = "Loot rules when announcement is made.  Use | as a line delimiter.",
			multiline = true, width="full",	
			get = function(info) return(DALoot.db.profile.lootRules) end,
			set = function(info, key) DALoot.db.profile.lootRules=key end
		},enablePriority = {
			order=1, type = "toggle",
			name = "Enable Priority Loot",
			desc = "Enables Priority rolls",
			get = function(info) return(DALoot.db.profile.enablePriority) end,
			set = function(info, key) DALoot.db.profile.enablePriority=key end
		}
	}
}
local defaultOptions = {
	profile = {
		enableDAL = true,
		enablePriority = false,
		bidSummaryCount = 5,
		bidTime = 15,
		countdownTime = 3,
		defaultSharder = "Daedre",
		outputChannel = "Raid Chat",
		raidAnnounce = true,
		lootRules = "When an item is announced, you will roll either Priority, Main or Offspec.  All rolls are made at the same time.|"..
		"You are only allowed one Priority roll per raid.  To roll Priority, do a"..
		" '/roll 300'.  |If the item is for the spec you attended the raid for, '/roll 200'.  And if it is an off-spec item for you, simply do a '/roll'.",
		Colors={
			["Window"]={
				["Title"] = { r = 0, g = 0, b = 1, a = 1},
				["Background"]= { r = 24/255, g = 24/255, b = 24/255, a = 1},
				["Title Text"] = {r = 1, g = .84, b = 0, a = 1},
			},
			["Bar"]={
				["Bar Text"] = {r = 1, g = 1, b = 1},
				["Total Bar"] = { r = 0.75, g = 0.75, b = 0.75},
			},
			["Other Windows"]={
				["Title"] = { r = 0, g = 0, b = 1, a = 1},
				["Background"]= { r = 24/255, g = 24/255, b = 24/255, a = 1},
				["Title Text"] = {r = 1, g = 1, b = 1, a = 1},
			},
			["Detail Window"]={
			},
			["Class"]={
				["HUNTER"] = { r = 0.67, g = 0.83, b = 0.45, a=1 },
				["WARLOCK"] = { r = 0.58, g = 0.51, b = 0.79, a=1 },
				["PRIEST"] = { r = 1.0, g = 1.0, b = 1.0, a=1 },
				["PALADIN"] = { r = 0.96, g = 0.55, b = 0.73, a=1 },
				["MAGE"] = { r = 0.41, g = 0.8, b = 0.94, a=1 },
				["ROGUE"] = { r = 1.0, g = 0.96, b = 0.41, a=1 },
				["DRUID"] = { r = 1.0, g = 0.49, b = 0.04, a=1 },
				["SHAMAN"] = { r = 0.14, g = 0.35, b = 1.0, a=1 },
				["WARRIOR"] = { r = 0.78, g = 0.61, b = 0.43, a=1 },
				["DEATHKNIGHT"] = { r = 0.77, g = 0.12, b = 0.23, a=1 },
				["PET"] = { r = 0.09, g = 0.61, b = 0.55, a=1 },
--				["GUARDIAN"] = { r = 0.61, g = 0.09, b = 0.09 },
				["MOB"] = { r = 0.58, g = 0.24, b = 0.63, a=1 },
				["UNKNOWN"] = { r = 0.1, g = 0.1, b = 0.1, a=1 },
				["HOSTILE"] = { r = 0.7, g = 0.1, b = 0.1, a=1 },
				["UNGROUPED"] = { r = 0.63, g = 0.58, b = 0.24, a=1 },
			},
			["Realtime"]={
			},
			["Names"]={
			}
		},
		MainWindowVis=true,
		MainWindow={
			Buttons={
				ReportButton=true,
				FileButton=true,
				ConfigButton=true,
				ResetButton=true,
				LeftButton=true,
				RightButton=true,
			},
			RowHeight=14,
			RowSpacing=1,
			AutoHide=false,
			ShowScrollbar=true, 
			HideTotalBar=true,
			BarText=
			{
				RankNum =true,
				PerSec = true,
				Percent = true,
				NumFormat = 1,
			},
			Position={
				x = 0,
				y = 0,
				w = 140,
				h = 200,
			},
		}
	}
}

-- REGISTER_OPTIONS
-- Initialises the DALootDB SavedVariables and registers the base options
function DALoot:RegisterOptions()
	DALoot.db = LibStub("AceDB-3.0"):New("DALootDB", defaultOptions, "Default")
        DALoot.history = LibStub("AceDB-3.0"):New("DALootHistory")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("DALoot", options)
	DALoot.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("DALoot", "DALoot")
end
