-- Author      : jkonkle
-- Create Date : 6/23/2009 1:17:56 PM

DALoot = LibStub("AceAddon-3.0"):NewAddon("DALoot", "AceConsole-3.0", "AceEvent-3.0", "AceTimer-3.0", "AceComm-3.0", "AceSerializer-3.0")

DA_DEBUG = false;

function DALoot:OnInitialize()
    -- Called when the addon is loaded
    --LibStub("AceConfig-3.0"):RegisterOptionsTable("DALoot", options)
    self:RegisterOptions();
    self:RegisterVariables();
    --self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("DALoot", "DALoot")
    self:RegisterChatCommand("da", "ChatCommand")
    self:RegisterChatCommand("daloot", "ChatCommand")
    
    self:RegisterComm("DA_LOOT_ROLL")
    self:RegisterComm("DA_LOOT_COUNTDOWN")
    self:RegisterComm("DA_LOOT_ROLLEND")
    self:RegisterComm("DA_LOOT_WIN")
    self:RegisterComm("DA_LOOT_PLAYER_ROLL")

    -- Create a Tooltip window
    TempTooltip = CreateFrame("GameTooltip", "DATooltip", nil, "GameTooltipTemplate")
    TempTooltip:SetOwner(UIParent, "ANCHOR_NONE")
end

function DALoot:OnEnable()
    -- Called when the addon is enabled
    self:RegisterEvent("CHAT_MSG_SYSTEM")
    -- commented out raid and party member change notifications for now
    --self:RegisterEvent("PARTY_MEMBERS_CHANGED")
    --self:RegisterEvent("RAID_ROSTER_UPDATE")
end

function DALoot:OnDisable()
    -- Called when the addon is disabled
    self:UnregisterEvent("CHAT_MSG_SYSTEM")
    --self:UnregisterEvent("PARTY_MEMBERS_CHANGED")
    --self:UnregisterEvent("RAID_ROSTER_UPDATE")
end

-- Catch chat commands that start with DA or DALoot.
function DALoot:ChatCommand(input)
    if not input or input:trim() == "" then
        InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
    elseif (input == "show") then
        --Create the Main Window
        self:ShowMainWindow()
    elseif (input == "spam" or input == "rules") then
        DALoot:AnnounceRules()
    elseif (input == "test on") then
        DA_DEBUG = true;
        DALoot:DebugMsg("Test Mode Enabled")
    elseif (input == "test off") then
        DALoot:DebugMsg("Test Mode Disabled")
        DA_DEBUG = false;
    elseif GetItemInfo(input) then
	self:ManualActivate(input)
    else
        LibStub("AceConfigCmd-3.0").HandleCommand(DALoot, "da", "DALoot", input)
    end
end

function DALoot:CHAT_MSG_SYSTEM()
    local msg = arg1
    local itemString = ""
    local pattern = "(.+) rolls (%d+) %((%d+)%-(%d+)%)"   -- ROLL_PATTERN  -- loc this later

    -- get rid of nulls coming in...
    if not msg or msg:trim() == "" then
        return
    end

    -- Check to see if it's a /random roll:
    local player, roll, min_roll, max_roll, report, startIndex, endIndex
    if (string.find(msg, pattern)) then
            DALoot:DebugMsg("Roll made")
            _, _, player, roll, min_roll, max_roll = string.find(msg, pattern)
            DALoot:ProcessRoll(player, roll, min_roll, max_roll)
    end
end 

function DALoot:OnCommReceived(prefix, message, distribution, sender)
    if (prefix == "DA_LOOT_ROLL") then
        self:Notify(sender.." is starting a new loot roll on "..message)
        self:ShowRollWindow(message)
    elseif (prefix == "DA_LOOT_COUNTDOWN")  then
        self:UpdateWindow(message)
    elseif (prefix == "DA_LOOT_ROLLEND") then
        self:HideRollWindow()
    elseif (prefix == "DA_LOOT_WIN") then		-- Player won a roll

    elseif (prefix == "DA_LOOT_PLAYER_ROLL") then -- Player made a roll

    end
end

function DALoot:PARTY_MEMBERS_CHANGED()
   self:UpdatePlayers()
end

function DALoot:RAID_ROSTER_UPDATE()
   self:UpdatePlayers()
end

function DALoot:Announce(msg)
	SendChatMessage(msg, self.db.profile.outputChannel)
end 

function DALoot:Notify(msg)
	self:Print(msg);
end

function DALoot:DebugMsg(msg)
    if (DA_DEBUG) then
        self:Print("<Debug> "..msg);
    end
end 

local function split(str, pat)
    local t = {}  -- NOTE: use {n = 0} in Lua-5.0
    local fpat = "(.-)" .. pat
    local last_end = 1
    local s, e, cap = str:find(fpat, 1)

    if string.find(str, pat) == nil then
        return { str }
    end

    while s do
        if s ~= 1 or cap ~= "" then
            table.insert(t,cap)
        end
        last_end = e+1
        s, e, cap = str:find(fpat, last_end)
    end
    if last_end <= #str then
        cap = str:sub(last_end)
        table.insert(t, cap)
    end
    return t
end

function DALoot:AnnounceRules()
    local ruleLines = split(self.db.profile.lootRules, "|")
    for i,v in ipairs(ruleLines) do
        self:DAShowMsg(v)
    end
end

function DALoot:DAShowMsg(msg)
    if (msg~=nil or msg~= "") then
        self:Announce(msg)
    end
end

function DALoot:TransmitWin(player,roll,item)
   
end