--[[
    MainWindow.lua
    Author  : jkonkle
    Purpose : Main viewport window of DALoot
]]

local AceGUI = LibStub("AceGUI-3.0")

local function split(str, pat)
    local t = {}  -- NOTE: use {n = 0} in Lua-5.0
    local fpat = "(.-)" .. pat
    local last_end = 1
    local s, e, cap = str:find(fpat, 1)

    if string.find(str, pat) == nil then
        return { str }
    end

    while s do
        if s ~= 1 or cap ~= "" then
            table.insert(t,cap)
        end
        last_end = e+1
        s, e, cap = str:find(fpat, last_end)
    end
    if last_end <= #str then
        cap = str:sub(last_end)
        table.insert(t, cap)
    end
    return t
end

-- Callback function for selection of tree
local function TreeSelectGroup(container, event, group)
    local groupPath = split(group, "\001")
    local groupString = table.concat(groupPath, " ")

    container:ReleaseChildren()
    local desc = AceGUI:Create("Label")
    desc:SetText("This is "..groupString)
    desc:SetFullWidth(true)
    container:AddChild(desc)

    if groupString == "B D E" then
        
    end
end

-- function that draws the widgets for the first tab
local function DrawGroup1(container)

    --local button = AceGUI:Create("Button")
    --button:SetText("Reset Current")
    --button:SetWidth(200)
    --container:AddChild(button)

    local treeGroup = AceGUI:Create("TreeGroup")
    treeGroup:SetTree(tree)
    treeGroup:SetFullWidth(true)
    treeGroup:SetFullHeight(true)
    treeGroup:SetCallback("OnGroupSelected", TreeSelectGroup)
    container:AddChild(treeGroup)

end

-- function that draws the widgets for the second tab
local function DrawGroup2(container)
    
end

-- Callback function for Tab OnGroupSelected
local function TabSelectGroup(container, event, group)
    container:ReleaseChildren()
    if group == "tab1" then
        DrawGroup1(container)
    elseif group == "tab2" then
        DrawGroup2(container)
    end
end

function DALoot:ShowMainWindow()
    -- Create the frame container
    local frame = AceGUI:Create("Frame")
    frame:SetTitle("DALoot")
    frame:SetStatusText("DALoot Main Window")
    frame:SetCallback("OnClose", function(widget) AceGUI:Release(widget) end)
    -- Fill Layout - the TabGroup widget will fill the whole frame
    frame:SetLayout("Fill")

    -- Create the TabGroup
    local tab =  AceGUI:Create("TabGroup")
    tab:SetLayout("Flow")
    -- Setup which tabs to show
    tab:SetTabs({{text="Current", value="tab1"}, {text="History", value="tab2"}})
    -- Register callback
    tab:SetCallback("OnGroupSelected", TabSelectGroup)
    -- Set initial Tab (this will fire the OnGroupSelected callback)
    tab:SelectTab("tab1")
    -- add to the frame container
    frame:AddChild(tab)
end