-- Author      : jkonkle
-- Create Date : 6/24/2009 1:45:42 PM
-- Functions that relate to rolling

function DALoot:ProcessRoll(player, roll, min_roll, max_roll)
	roll = tonumber(roll)
	min_roll = tonumber(min_roll)
	max_roll = tonumber(max_roll)

	-- If not doing Priority
	if (not DALoot.db.profile.enablePriority and max_roll == 300) then
            return
	end

	-- Reject random rolls 
	if (not self.data.bDoingLoot) then
            DALoot:DebugMsg("Not doing loot at this time.")
            return
	end
	DALoot:Notify(player.." rolled "..roll.." on a max of "..max_roll);
	
	-- Check to see if roller is in Raid/Group
	--if (not self:IsInGroup(player)) then
	--	self:Announce(player.." is not in your group/raid!  Roll ignored.")
	--	return
	--end
	
	-- Reject cheaters
	if ((min_roll ~= 1) or not ((max_roll ==100) or (max_roll == 200) or (max_roll == 300))) then
            local cheat_msg = string.format(MSG_CHEAT, player, roll, min_roll, max_roll)
            self:Announce("<DALoot> "..cheat_msg)
            return
	end
	DALoot:DebugMsg("Checked Cheaters")

	DALoot:DebugMsg("Checking Valid roll")	
	-- We've determined it's a valid roll.  Acknowledge if configured to do so and do it only if this is the first roll of the player:
	if ((not DALoot.data.playersBid[player]) and (UnitName("player") ~= player)) then
            local ack = string.format(MSG_ACK, roll)
            -- Send pass message to player if he did pass on this roll
            if (roll == 0) then
                    ack = MSG_ACK_PASS
            end
            SendChatMessage(ack, "WHISPER", nil, player)
            DALoot:Notify(ack)
	end

        if (not DALoot.db.char.PlayerLoot) then
            DALoot.db.char.PlayerLoot = {}
        end
        if (not DALoot.db.char.PlayerLoot[player]) then
            DALoot.db.char.PlayerLoot[player] = {}
        end
	
	-- No 2 priority rolls...
	--if ( DALoot.db.char.PlayerLoot[player][1]==true and max_roll == 300) then
        --    DALoot:Notify("Dropping second roll to Main for Priority from:"..player);
        --    SendChatMessage("You have rolled Priority already.  Roll was downgraded.", "WHISPER", nil, player)
        --    roll=roll-100
        --    max_roll = 200
	--end
	
	-- Reject Dups and mark player as rolled
	if (not DALoot.data.playersBid[player]) then
            DALoot.data.playersBid[player] = true
	else
            -- Duplicate roll!
            local dupe_msg = string.format(MSG_DUPE, player)
            DALoot:Notify(dupe_msg);
            return
	end

	self:DebugMsg("Checking Valid roll")	
	-- We've determined it's a valid roll.  Acknowledge if configured to do so and do it only if this is the first roll of the player:
	if ((not DALoot.data.playersBid[player]) and (UnitName("player") ~= player)) then
            local ack = string.format(MSG_ACK, roll)
            -- Send pass message to player if he did pass on this roll
            if (roll == 0) then
                ack = MSG_ACK_PASS
            end
            SendChatMessage(ack, "WHISPER", "", player)
            DALoot:Notify(ack)
	end
	
	DALoot:DebugMsg("Adding roll to table")
	
	local rollTable 
	
	if max_roll == 300 then
            -- Increment Counter
            DALoot.db.char.PlayerLoot[player][3]=DALoot.db.char.PlayerLoot[player][3]+1
            rollTable = DALoot.data.OMGRolls
	elseif max_roll == 200 then
            -- Increment Counter
            DALoot.db.char.PlayerLoot[player][5]=DALoot.db.char.PlayerLoot[player][5]+1
            rollTable = DALoot.data.MainRolls
	else
            -- Increment Counter
            DALoot.db.char.PlayerLoot[player][7]=DALoot.db.char.PlayerLoot[player][7]+1
            rollTable = DALoot.data.OffRolls
	end
	
	-- Add roll to table of rolls
	if (#rollTable==0) then
            DALoot:DebugMsg("No existing bids - Adding new bid")	
            rollTable[1] = {player, roll, min_roll, max_roll}
	else -- Insert the roll into the list at the proper spot:
            DALoot:DebugMsg("Existing bids")
            local i = 1  
            while ((rollTable[i] ~= nil) and (rollTable[i][2] >= roll)) do
                    i=i+1
            end
            table.insert(rollTable, i, {player, roll, min_roll, max_roll})
	end
end

-- Checks if the unit is in the current group of the player, return always true for the local player!
function IsInGroup(playerName)
    -- Check if the rolling player is in your group
    local isInParty = false
    -- Check if in party or raid group
    if (GetNumRaidMembers() > 0) then
    local raidMemberString = "raid"
    for i = 1, GetNumRaidMembers(), 1 do
        raidMemberString = "raid" --reset string		
        raidMemberString = raidMemberString .. i --add the suffix of corresponding player
        if (UnitName(raidMemberString) == playerName) then
                isInParty = true	
        end
    end

    elseif (GetNumPartyMembers() > 0) then
        local partyMemberString = "party"
        for i = 1, GetNumPartyMembers(), 1 do
            partyMemberString = "party" --reset string		
            partyMemberString = partyMemberString .. i --add the suffix of corresponding player
            if (UnitName(partyMemberString) == playerName) then
                isInParty = true	
            end
        end
    end

    if (UnitName("player") == playerName) then
        isInParty = true
    end

    return isInParty
end

function DALoot:ShowTopResults()
    local summaryCount = tonumber(DALoot.db.profile.bidSummaryCount)
    if (summaryCount > 0) then
            local rollTable 
            local TableName = ""
    DALoot:Announce("Top rolls:")
    DALoot:Announce("============");
		
    if (DALoot.db.profile.enablePriority) then
        if (#DALoot.data.OMGRolls>0) then
            rollTable = DALoot.data.OMGRolls
            TableName = "(300)"
            summaryCount = DALoot:PrintTable(TableName, rollTable, summaryCount)
        else
            DALoot:Announce("No Priority (300) rolls...") 
        end
    end

    if (#DALoot.data.MainRolls>0) then
        rollTable = self.data.MainRolls
        TableName = "(200)"
        summaryCount = DALoot:PrintTable(TableName, rollTable, summaryCount)
    else
        DALoot:Announce("No Main Spec (200) rolls...") 
    end

    if (#DALoot.data.OffRolls>0) then
        TableName = "(100)"
        rollTable = DALoot.data.OffRolls
        summaryCount = DALoot:PrintTable(TableName, rollTable, summaryCount)
    else
        DALoot:Announce("No Off Spec (100) rolls...")
    end

    DALoot:Announce("============");
    DALoot:GetWinner()
    end
end 

function DALoot:PrintTable(TableName, rollTable, countLeft)
    local summaryCount = tonumber(DALoot.db.profile.bidSummaryCount)
    local roll_counter_target = table.getn(rollTable)
    if (roll_counter_target > summaryCount) then
        roll_counter_target = summaryCount
    end
    local roll_counter = 1

    while (roll_counter >= 1 and roll_counter <= roll_counter_target) do
        if (countLeft>0) then
            DALoot:Announce(TableName.." "..string.format(MSG_ROLLS, roll_counter, rollTable[roll_counter][1], rollTable[roll_counter][2]))
            countLeft = countLeft-1
        end 
        roll_counter = roll_counter + 1
    end

    return countLeft
end

function DALoot:GetWinner()
    local rollTable
    if (#DALoot.data.OMGRolls>0) then
        rollTable = DALoot.data.OMGRolls
    elseif (#DALoot.data.MainRolls>0) then
        rollTable = DALoot.data.MainRolls
    else
        rollTable = DALoot.data.OffRolls
    end
	
    if (#rollTable>1 and (rollTable[1][2] == rollTable[2][2])) then -- check for 1-2 tie
        DALoot:Announce("TIE between "..rollTable[1][1].." and "..rollTable[2][1].." with a roll of "..rollTable[1][2])
    else
        DALoot:Announce(string.format(MSG_WINNER, rollTable[1][1], self.data.strItem, rollTable[1][2], rollTable[1][3], rollTable[1][4]))
        -- Increment Win Counter
        local rollCat = rollTable[1][4]
        local player = rollTable[1][1]
        if rollCat == 300 then
            DALoot.data.Wins[1]=DALoot.data.Wins[1]+1
            DALoot.db.char.PlayerLoot[player][1]=true
            DALoot.db.char.PlayerLoot[player][2]=DALoot.db.char.PlayerLoot[player][2]+1
            DALoot:CheckPriorityBox(player)
        elseif rollCat == 200 then
            DALoot.data.Wins[2]=DALoot.data.Wins[2]+1
            DALoot.db.char.PlayerLoot[player][4]=DALoot.db.char.PlayerLoot[player][4]+1
        else
            DALoot.data.Wins[3]=DALoot.data.Wins[3]+1
            DALoot.db.char.PlayerLoot[player][6]=DALoot.db.char.PlayerLoot[player][6]+1
        end

        -- Add the item to the Player winnings
        local lootTable = DALoot.db.char.PlayerLoot[player][8]
        if (#lootTable==0) then
            lootTable[1] = {rollCat, self.data.strItem}
        else 
            local i = 1  
            while (lootTable[i] ~= nil) do
                i=i+1
            end
            table.insert(lootTable, i, {rollCat, self.data.strItem})
        end
    end	
end