function DALoot:CreateFrame(Name, Title, Height, Width, ShowFunc, HideFunc)
	local theFrame=CreateFrame("Frame", Name,UIParent)

	theFrame:ClearAllPoints()
	theFrame:SetPoint("CENTER",UIParent)
	theFrame:SetHeight(Height)
	theFrame:SetWidth(Width)

	theFrame:SetBackdrop({
		bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 16,
		edgeFile = "Interface\\AddOns\\DALoot\\textures\\otravi-semi-full-border", edgeSize = 32,
		insets = {left = 1, right = 1, top = 20, bottom = 1},
	})
	theFrame:SetBackdropBorderColor(0.0,0.0,1.0)
	theFrame:SetBackdropColor(24/255, 24/255, 24/255)

	if Name == "DALoot_MainWindow" then
		DALoot.Colors:RegisterBorder("Window","Title",theFrame)
		DALoot.Colors:RegisterBackground("Window","Background",theFrame)
	else
		DALoot.Colors:RegisterBorder("Other Windows","Title",theFrame)
		DALoot.Colors:RegisterBackground("Other Windows","Background",theFrame)
	end
	
	theFrame:EnableMouse(true)
	theFrame:SetMovable(true)

	theFrame:SetScript("OnMouseDown", function(this) 
						if ( ( ( not this.isLocked ) or ( this.isLocked == 0 ) ) and ( arg1 == "LeftButton" ) ) then
						  --DALoot:SetWindowTop(this)
						  this:StartMoving();
						  this.isMoving = true;
						 end
						end)
	theFrame:SetScript("OnMouseUp", function(this) 
						if ( this.isMoving ) then
						  this:StopMovingOrSizing();
						  this.isMoving = false;

						  if this.SavePosition then
							this:SavePosition()
						  end
						 end
						end)
	theFrame.ShowFunc=ShowFunc	
	theFrame:SetScript("OnShow", function(this)
						--DALoot:SetWindowTop(this)
						if this.ShowFunc then
							this:ShowFunc()
						end
						end)
	theFrame.HideFunc=HideFunc
	theFrame:SetScript("OnHide", function(this) 
						if ( this.isMoving ) then
						  this:StopMovingOrSizing();
						  this.isMoving = false;
						 end
						 if this.HideFunc then
							this:HideFunc()
						 end
						end)
	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetPoint("TOPLEFT",theFrame,"TOPLEFT",6,-15)
	theFrame.Title:SetTextColor(1.0,1.0,1.0,1.0)
	theFrame.Title:SetText(Title)
	DALoot:AddFontString(theFrame.Title)

	if Name == "DALoot_MainWindow" then
		DALoot.Colors:UnregisterItem(theFrame.Title)
		DALoot.Colors:RegisterFont("Window","Title Text",theFrame.Title)
	else
		DALoot.Colors:UnregisterItem(theFrame.Title)
		DALoot.Colors:RegisterFont("Other Windows","Title Text",theFrame.Title)
	end
	
	theFrame.CloseButton=CreateFrame("Button",nil,theFrame)
	theFrame.CloseButton:SetNormalTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Up.blp")
	theFrame.CloseButton:SetPushedTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Down.blp")
	theFrame.CloseButton:SetHighlightTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Highlight.blp")
	theFrame.CloseButton:SetWidth(20)
	theFrame.CloseButton:SetHeight(20)
	theFrame.CloseButton:SetPoint("TOPRIGHT",theFrame,"TOPRIGHT",-4,-12)
	theFrame.CloseButton:SetScript("OnClick",function(this) this:GetParent():Hide() end)

	return theFrame
end


function DALoot:SetupScrollbar(name)
	local Thumb=getglobal(name.."ScrollBarThumbTexture")
	Thumb:SetTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-Knob")
	Thumb:SetVertexColor(0,0,1)
	DALoot.Colors:RegisterTexture("Window","Title",Thumb)

	local Up=getglobal(name.."ScrollBarScrollUpButton")
	Up:SetNormalTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollUpButton-Up")
	Up:SetPushedTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollUpButton-Up")
	Up:SetDisabledTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollUpButton-Disabled")
	Up:SetHighlightTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollUpButton-Highlight")

	if not Up.Overlay then
		Up.Overlay=Up:CreateTexture(nil,"OVERLAY")
		Up.Overlay:SetAllPoints(Up)
		Up.Overlay:SetTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollUpButton-Overlay")
		Up.Overlay:SetVertexColor(0,0,1)
		Up.Overlay:SetTexCoord(0.25,0.75,0.25,0.75)
		Up.Overlay:SetBlendMode("MOD")
		DALoot.Colors:RegisterTexture("Window","Title",Up.Overlay)
	end

	local Down=getglobal(name.."ScrollBarScrollDownButton")
	Down:SetNormalTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollDownButton-Up")
	Down:SetPushedTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollDownButton-Up")
	Down:SetDisabledTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollDownButton-Disabled")
	Down:SetHighlightTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollDownButton-Highlight")

	if not Down.Overlay then
		Down.Overlay=Up:CreateTexture(nil,"OVERLAY")
		Down.Overlay:SetAllPoints(Down)
		Down.Overlay:SetTexture("Interface\\AddOns\\DALoot\\textures\\scrollbar\\UI-ScrollBar-ScrollDownButton-Overlay")
		Down.Overlay:SetVertexColor(0,0,1)
		Down.Overlay:SetTexCoord(0.25,0.75,0.25,0.75)
		Down.Overlay:SetBlendMode("MOD")

		DALoot.Colors:RegisterTexture("Window","Title",Down.Overlay)
	end
	
end

function DALoot:HideScrollbarElements(name)
	local Thumb=getglobal(name.."ScrollBarThumbTexture")
	local Up=getglobal(name.."ScrollBarScrollUpButton")
	local Down=getglobal(name.."ScrollBarScrollDownButton")


	Thumb:Hide()
	Up:Hide()
	Up:EnableMouse(false)
	if Up.Overlay then Up.Overlay:Hide() end
	Down:Hide()
	Down:EnableMouse(false)
	if Down.Overlay then Down.Overlay:Hide() end
	
	local scrollbar=getglobal(name.."ScrollBar")
	scrollbar:EnableMouse(false)
end

function DALoot:ShowScrollbarElements(name)
	local Thumb=getglobal(name.."ScrollBarThumbTexture")
	local Up=getglobal(name.."ScrollBarScrollUpButton")
	local Down=getglobal(name.."ScrollBarScrollDownButton")

	Thumb:Show()
	Up:EnableMouse(true)
	Up:Show()
	if Up.Overlay then Up.Overlay:Show() end
	Down:EnableMouse(true)
	Down:Show()
	if Down.Overlay then Down.Overlay:Show() end
	local scrollbar=getglobal(name.."ScrollBar")
	scrollbar:EnableMouse(true)
end

